public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Rusty Russell <rusty@rustcorp.com.au>
To: Russell King <rmk+lkml@arm.linux.org.uk>
Cc: Linux Kernel List <linux-kernel@vger.kernel.org>,
	Andrew Morton <akpm@osdl.org>
Subject: Re: Am I paranoid or is everyone out to break my kernel builds (Breakage in drivers/pcmcia)
Date: Thu, 21 Oct 2004 19:40:25 +1000	[thread overview]
Message-ID: <1098351606.10571.359.camel@localhost.localdomain> (raw)
In-Reply-To: <20041021100903.A3089@flint.arm.linux.org.uk>

On Thu, 2004-10-21 at 19:09, Russell King wrote:
> It would appear that this change:
> 
> -module_param_array(irq_list, int, irq_list_count, 0444);
> +module_param_array(irq_list, int, &irq_list_count, 0444);
> 
> given:
> 
> static int irq_list[16];
> static int irq_list_count;
> 
> breaks PCMCIA drivers.  Why?
> 
> #define module_param_array(name, type, num, perm)               \
>         module_param_array_named(name, name, type, num, perm)
> 
> #define module_param_array_named(name, array, type, num, perm)          \
>         static struct kparam_array __param_arr_##name                   \
>         = { ARRAY_SIZE(array), &num, param_set_##type, param_get_##type,\
>             sizeof(array[0]), array };                                  \
>         module_param_call(name, param_array_set, param_array_get,       \
>                           &__param_arr_##name, perm)

I'm confused. Andrew, what happened to this part of my patch?

diff -urpN --exclude TAGS -X /home/rusty/devel/kernel/kernel-patches/current-dontdiff --minimal .22800-linux-2.6-bk/include/linux/moduleparam.h .22800-linux-2.6-bk.updated/include/linux/moduleparam.h
--- .22800-linux-2.6-bk/include/linux/moduleparam.h	2004-10-19 14:34:21.000000000 +1000
+++ .22800-linux-2.6-bk.updated/include/linux/moduleparam.h	2004-10-20 17:13:45.000000000 +1000
@@ -129,16 +129,16 @@ extern int param_set_invbool(const char 
 extern int param_get_invbool(char *buffer, struct kernel_param *kp);
 #define param_check_invbool(name, p) __param_check(name, p, int)
 
 /* Comma-separated array: num is set to number they actually specified. */
 #define module_param_array_named(name, array, type, num, perm)		\
 	static struct kparam_array __param_arr_##name			\
-	= { ARRAY_SIZE(array), &num, param_set_##type, param_get_##type,\
+	= { ARRAY_SIZE(array), nump, param_set_##type, param_get_##type,\
 	    sizeof(array[0]), array };					\
 	module_param_call(name, param_array_set, param_array_get, 	\
 			  &__param_arr_##name, perm)
 
-#define module_param_array(name, type, num, perm)		\
-	module_param_array_named(name, name, type, num, perm)
+#define module_param_array(name, type, nump, perm)		\
+	module_param_array_named(name, name, type, nump, perm)
 
 extern int param_array_set(const char *val, struct kernel_param *kp);
 extern int param_array_get(char *buffer, struct kernel_param *kp);
@@ -129,16 +129,16 @@ extern int param_set_invbool(const char 
 #define param_check_invbool(name, p) __param_check(name, p, int)
 
-/* Comma-separated array: num is set to number they actually specified. */
-#define module_param_array_named(name, array, type, num, perm)		\
+/* Comma-separated array: *nump is set to number they actually specified. */
+#define module_param_array_named(name, array, type, nump, perm)		\
 	static struct kparam_array __param_arr_##name			\


Rusty.
-- 
Anyone who quotes me in their signature is an idiot -- Rusty Russell


      parent reply	other threads:[~2004-10-21  9:56 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2004-10-21  9:09 Am I paranoid or is everyone out to break my kernel builds (Breakage in drivers/pcmcia) Russell King
2004-10-21  9:31 ` Andrew Morton
2004-10-21  9:50   ` Russell King
2004-10-21 17:02     ` Andrew Morton
2004-10-21 23:46     ` Rusty Russell
2004-10-21  9:40 ` Rusty Russell [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1098351606.10571.359.camel@localhost.localdomain \
    --to=rusty@rustcorp.com.au \
    --cc=akpm@osdl.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=rmk+lkml@arm.linux.org.uk \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox